# Getting started

Move your app forward with the Uber API

## How to Build


You must have Python ```2 >=2.7.9``` or Python ```3 >=3.4``` installed on your system to install and run this SDK. This SDK package depends on other Python packages like nose, jsonpickle etc. 
These dependencies are defined in the ```requirements.txt``` file that comes with the SDK.
To resolve these dependencies, you can use the PIP Dependency manager. Install it by following steps at [https://pip.pypa.io/en/stable/installing/](https://pip.pypa.io/en/stable/installing/).

Python and PIP executables should be defined in your PATH. Open command prompt and type ```pip --version```.
This should display the version of the PIP Dependency Manager installed if your installation was successful and the paths are properly defined.

* Using command line, navigate to the directory containing the generated files (including ```requirements.txt```) for the SDK.
* Run the command ```pip install -r requirements.txt```. This should install all the required dependencies.

![Building SDK - Step 1](https://apidocs.io/illustration/python?step=installDependencies&workspaceFolder=Uber%20API-Python)


## How to Use

The following section explains how to use the Somerandom SDK package in a new project.

### 1. Open Project in an IDE

Open up a Python IDE like PyCharm. The basic workflow presented here is also applicable if you prefer using a different editor or IDE.

![Open project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=pyCharm)

Click on ```Open``` in PyCharm to browse to your generated SDK directory and then click ```OK```.

![Open project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=openProject0&workspaceFolder=Uber%20API-Python)     

The project files will be displayed in the side bar as follows:

![Open project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=openProject1&workspaceFolder=Uber%20API-Python&projectName=somerandom)     

### 2. Add a new Test Project

Create a new directory by right clicking on the solution name as shown below:

![Add a new project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=createDirectory&workspaceFolder=Uber%20API-Python&projectName=somerandom)

Name the directory as "test"

![Add a new project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=nameDirectory)
   
Add a python file to this project with the name "testsdk"

![Add a new project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=createFile&workspaceFolder=Uber%20API-Python&projectName=somerandom)

Name it "testsdk"

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=nameFile)

In your python file you will be required to import the generated python library using the following code lines

```Python
from somerandom.somerandom_client import SomerandomClient
```

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=projectFiles&workspaceFolder=Uber%20API-Python&libraryName=somerandom.somerandom_client&projectName=somerandom&className=SomerandomClient)

After this you can write code to instantiate an API client object, get a controller object and  make API calls. Sample code is given in the subsequent sections.

### 3. Run the Test Project

To run the file within your test project, right click on your Python file inside your Test project and click on ```Run```

![Run Test Project - Step 1](https://apidocs.io/illustration/python?step=runProject&workspaceFolder=Uber%20API-Python&libraryName=somerandom.somerandom_client&projectName=somerandom&className=SomerandomClient)


## How to Test

You can test the generated SDK and the server with automatically generated test
cases. unittest is used as the testing framework and nose is used as the test
runner. You can run the tests as follows:

  1. From terminal/cmd navigate to the root directory of the SDK.
  2. Invoke ```pip install -r test-requirements.txt```
  3. Invoke ```nosetests```

## Initialization

### Authentication
In order to setup authentication and initialization of the API client, you need the following information.

| Parameter | Description |
|-----------|-------------|
| server_token | TODO: add a description |



API client can be initialized as following.

```python
# Configuration parameters and credentials
server_token = 'server_token'

client = SomerandomClient(server_token)
```



# Class Reference

## <a name="list_of_controllers"></a>List of Controllers

* [ProductsController](#products_controller)
* [EstimatesController](#estimates_controller)
* [UserController](#user_controller)

## <a name="products_controller"></a>![Class: ](https://apidocs.io/img/class.png ".ProductsController") ProductsController

### Get controller instance

An instance of the ``` ProductsController ``` class can be accessed from the API Client.

```python
 products_controller = client.products
```

### <a name="get_products_get"></a>![Method: ](https://apidocs.io/img/method.png ".ProductsController.get_products_get") get_products_get

> The Products endpoint returns information about the Uber products offered at a given location. The response includes the display name and other details about each product, and lists the products in the proper display order.

```python
def get_products_get(self,
                         latitude,
                         longitude)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| latitude |  ``` Required ```  | Latitude component of location. |
| longitude |  ``` Required ```  | Longitude component of location. |



#### Example Usage

```python
latitude = 52.9965383387155
longitude = 52.9965383387155

result = products_controller.get_products_get(latitude, longitude)

```

#### Errors

| Error Code | Error Description |
|------------|-------------------|
| 0 | Unexpected error |




[Back to List of Controllers](#list_of_controllers)

## <a name="estimates_controller"></a>![Class: ](https://apidocs.io/img/class.png ".EstimatesController") EstimatesController

### Get controller instance

An instance of the ``` EstimatesController ``` class can be accessed from the API Client.

```python
 estimates_controller = client.estimates
```

### <a name="get_estimates_time_get"></a>![Method: ](https://apidocs.io/img/method.png ".EstimatesController.get_estimates_time_get") get_estimates_time_get

> The Time Estimates endpoint returns ETAs for all products offered at a given location, with the responses expressed as integers in seconds. We recommend that this endpoint be called every minute to provide the most accurate, up-to-date ETAs.

```python
def get_estimates_time_get(self,
                               start_latitude,
                               start_longitude,
                               customer_uuid=None,
                               product_id=None)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| startLatitude |  ``` Required ```  | Latitude component of start location. |
| startLongitude |  ``` Required ```  | Longitude component of start location. |
| customerUuid |  ``` Optional ```  | Unique customer identifier to be used for experience customization. |
| productId |  ``` Optional ```  | Unique identifier representing a specific product for a given latitude & longitude. |



#### Example Usage

```python
start_latitude = 52.9965383387155
start_longitude = 52.9965383387155
customer_uuid = uuid.uuid4()
product_id = 'product_id'

result = estimates_controller.get_estimates_time_get(start_latitude, start_longitude, customer_uuid, product_id)

```

#### Errors

| Error Code | Error Description |
|------------|-------------------|
| 0 | Unexpected error |




### <a name="get_estimates_price_get"></a>![Method: ](https://apidocs.io/img/method.png ".EstimatesController.get_estimates_price_get") get_estimates_price_get

> The Price Estimates endpoint returns an estimated price range for each product offered at a given location. The price estimate is provided as a formatted string with the full price range and the localized currency symbol.<br><br>The response also includes low and high estimates, and the [ISO 4217](http://en.wikipedia.org/wiki/ISO_4217) currency code for situations requiring currency conversion. When surge is active for a particular product, its surge_multiplier will be greater than 1, but the price estimate already factors in this multiplier.

```python
def get_estimates_price_get(self,
                                start_latitude,
                                start_longitude,
                                end_latitude,
                                end_longitude)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| startLatitude |  ``` Required ```  | Latitude component of start location. |
| startLongitude |  ``` Required ```  | Longitude component of start location. |
| endLatitude |  ``` Required ```  | Latitude component of end location. |
| endLongitude |  ``` Required ```  | Longitude component of end location. |



#### Example Usage

```python
start_latitude = 52.9965383387155
start_longitude = 52.9965383387155
end_latitude = 52.9965383387155
end_longitude = 52.9965383387155

result = estimates_controller.get_estimates_price_get(start_latitude, start_longitude, end_latitude, end_longitude)

```

#### Errors

| Error Code | Error Description |
|------------|-------------------|
| 0 | Unexpected error |




[Back to List of Controllers](#list_of_controllers)

## <a name="user_controller"></a>![Class: ](https://apidocs.io/img/class.png ".UserController") UserController

### Get controller instance

An instance of the ``` UserController ``` class can be accessed from the API Client.

```python
 user_controller = client.user
```

### <a name="get_me_get"></a>![Method: ](https://apidocs.io/img/method.png ".UserController.get_me_get") get_me_get

> The User Profile endpoint returns information about the Uber user that has authorized with the application.

```python
def get_me_get(self)
```

#### Example Usage

```python

result = user_controller.get_me_get()

```

#### Errors

| Error Code | Error Description |
|------------|-------------------|
| 0 | Unexpected error |




### <a name="get_history_get"></a>![Method: ](https://apidocs.io/img/method.png ".UserController.get_history_get") get_history_get

> The User Activity endpoint returns data about a user's lifetime activity with Uber. The response will include pickup locations and times, dropoff locations and times, the distance of past requests, and information about which products were requested.<br><br>The history array in the response will have a maximum length based on the limit parameter. The response value count may exceed limit, therefore subsequent API requests may be necessary.

```python
def get_history_get(self,
                        offset=None,
                        limit=None)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| offset |  ``` Optional ```  | Offset the list of returned results by this amount. Default is zero. |
| limit |  ``` Optional ```  | Number of items to retrieve. Default is 5, maximum is 100. |



#### Example Usage

```python
offset = 52
limit = 52

result = user_controller.get_history_get(offset, limit)

```

#### Errors

| Error Code | Error Description |
|------------|-------------------|
| 0 | Unexpected error |




[Back to List of Controllers](#list_of_controllers)



